@@ -81,8 +81,19 @@
 #' @inheritParams statsExpressions::expr_meta_random
 #' @inheritParams ggbetweenstats
 #'
-#' @note **Important**: The function assumes that you have already downloaded
-#'   the needed package (`metafor`, `metaplus`, or `metaBMA`) for meta-analysis.
+#' @note
+#'
+#' **Important**: In case you want to carry out meta-analysis using this
+#' function, it assumes that you have already downloaded the needed package
+#' (`metafor`, `metaplus`, or `metaBMA`) for meta-analysis.
+#'
+#' 1. All rows of regression estimates where either of the following
+#'   quantities is `NA` will be removed if labels are requested: `estimate`,
+#'   `statistic`, `p.value`.
+#'
+#' 2. Given the rapid pace at which new methods are added to these packages, it
+#'   is recommended that you install the GitHub versions of `parameters` and
+#'   `performance` in order to make most of this function.
 #'
 #' @import ggplot2
 #' @importFrom rlang exec !!! !!
@@ -97,109 +108,24 @@
 #' @references
 #' \url{https://indrajeetpatil.github.io/ggstatsplot/articles/web_only/ggcoefstats.html}
 #'
-#' @note
-#' 1. All rows of regression estimates where either of the following
-#'   quantities is `NA` will be removed if labels are requested: `estimate`,
-#'   `statistic`, `p.value`.
-#'
-#' 2. Given the rapid pace at which new methods are added to these packages, it
-#'   is recommended that you install the GitHub versions of `parameters` and
-#'   `performance` in order to make most of this function.
 #'
 #' @examples
 #' \donttest{
 #' # for reproducibility
 #' set.seed(123)
-#'
-#' # -------------- with model object --------------------------------------
+#' library(ggstatsplot)
 #'
 #' # model object
 #' mod <- lm(formula = mpg ~ cyl * am, data = mtcars)
 #'
 #' # to get a plot
-#' ggstatsplot::ggcoefstats(x = mod, output = "plot")
+#' ggcoefstats(x = mod, output = "plot")
 #'
 #' # to get a tidy dataframe
-#' ggstatsplot::ggcoefstats(x = mod, output = "tidy")
+#' ggcoefstats(x = mod, output = "tidy")
 #'
 #' # to get a glance summary
-#' ggstatsplot::ggcoefstats(x = mod, output = "glance")
-#'
-#' # -------------- with custom dataframe -----------------------------------
-#'
-#' # creating a dataframe
-#' df <-
-#'   structure(
-#'     list(
-#'       term = structure(
-#'         c(3L, 4L, 1L, 2L, 5L),
-#'         .Label = c(
-#'           "Africa",
-#'           "Americas", "Asia", "Europe", "Oceania"
-#'         ),
-#'         class = "factor"
-#'       ),
-#'       estimate = c(
-#'         0.382047603321706,
-#'         0.780783111514665,
-#'         0.425607573765058,
-#'         0.558365541235078,
-#'         0.956473848429961
-#'       ),
-#'       std.error = c(
-#'         0.0465576338644502,
-#'         0.0330218199731529,
-#'         0.0362834986178494,
-#'         0.0480571500648261,
-#'         0.062215818388157
-#'       ),
-#'       statistic = c(
-#'         8.20590677855356,
-#'         23.6444603038067,
-#'         11.7300588415607,
-#'         11.6187818146078,
-#'         15.3734833553524
-#'       ),
-#'       conf.low = c(
-#'         0.290515146096969,
-#'         0.715841986960399,
-#'         0.354354575031406,
-#'         0.46379116008131,
-#'         0.827446138277154
-#'       ),
-#'       conf.high = c(
-#'         0.473580060546444,
-#'         0.845724236068931,
-#'         0.496860572498711,
-#'         0.652939922388847,
-#'         1.08550155858277
-#'       ),
-#'       p.value = c(
-#'         3.28679518728519e-15,
-#'         4.04778497135963e-75,
-#'         7.59757330804449e-29,
-#'         5.45155840151592e-26,
-#'         2.99171217913312e-13
-#'       ),
-#'       df.error = c(
-#'         394L, 358L, 622L,
-#'         298L, 22L
-#'       )
-#'     ),
-#'     row.names = c(NA, -5L),
-#'     class = c(
-#'       "tbl_df",
-#'       "tbl", "data.frame"
-#'     )
-#'   )
-#'
-#' # plotting the dataframe
-#' ggstatsplot::ggcoefstats(
-#'   x = df,
-#'   statistic = "t",
-#'   meta.analytic.effect = TRUE,
-#'   k = 3
-#' )
+#' ggcoefstats(x = mod, output = "glance")
 #' }
 #' @export
 
@@ -382,9 +308,10 @@ ggcoefstats <- function(x,
   # for non-dataframe objects
   if (isTRUE(insight::is_model(x))) {
     # creating glance dataframe
-    suppressWarnings(glance_df <-
-      performance::model_performance(x, verbose = FALSE) %>%
-      parameters::standardize_names(style = "broom"))
+    glance_df <- performance::model_performance(x, verbose = FALSE)
+
+    # rename to `broom` convention
+    if (!is.null(glance_df)) glance_df %<>% parameters::standardize_names(style = "broom")
 
     # no meta-analysis in this context
     meta.analytic.effect <- FALSE
@@ -410,18 +337,21 @@ ggcoefstats <- function(x,
     meta.type <- ipmisc::stats_type_switch(meta.type)
 
     # results from frequentist random-effects meta-analysis
-    subtitle <- statsExpressions::expr_meta_random(tidy_df, type = meta.type, k = k)
+    subtitle_df <- statsExpressions::expr_meta_random(tidy_df, type = meta.type, k = k)
+
+    subtitle <- subtitle_df$expression[[1]]
 
     # results from Bayesian random-effects meta-analysis (only for parametric)
     if (meta.type == "parametric" && isTRUE(bf.message)) {
-      caption <-
+      caption_df <-
         statsExpressions::expr_meta_random(
           top.text = caption,
           type = "bayes",
-          output = "expression",
           data = tidy_df,
           k = k
         )
+
+      caption <- caption_df$expression[[1]]
     }
   }
 
