@@ -44,7 +44,6 @@
 #'   x = color,
 #'   y = clarity,
 #'   grouping.var = cut,
-#'   title.prefix = "Quality",
 #'   plotgrid.args = list(nrow = 2)
 #' )
 #' }
@@ -56,7 +55,6 @@ grouped_ggbarstats <- function(data,
                                y,
                                counts = NULL,
                                grouping.var,
-                               title.prefix = NULL,
                                output = "plot",
                                plotgrid.args = list(),
                                annotation.args = list(),
@@ -64,9 +62,6 @@ grouped_ggbarstats <- function(data,
 
   # ======================== preparing dataframe =============================
 
-  # if `title.prefix` is not provided, use the variable `grouping.var` name
-  if (is.null(title.prefix)) title.prefix <- rlang::as_name(rlang::ensym(grouping.var))
-
   # creating a dataframe
   df <-
     dplyr::select(.data = data, {{ grouping.var }}, {{ x }}, {{ y }}, {{ counts }}) %>%
@@ -77,7 +72,7 @@ grouped_ggbarstats <- function(data,
   # creating a list of plots using `pmap`
   plotlist_purrr <-
     purrr::pmap(
-      .l = list(data = df, title = paste0(title.prefix, ": ", names(df))),
+      .l = list(data = df, title = names(df)),
       .f = ggstatsplot::ggbarstats,
       # put common parameters here
       x = {{ x }},
