@@ -38,7 +38,6 @@
 #'   y = manufacturer,
 #'   grouping.var = cyl,
 #'   test.value = 15.5,
-#'   title.prefix = "cylinder count",
 #'   ggplot.component = ggplot2::scale_x_continuous(
 #'     sec.axis = ggplot2::dup_axis(),
 #'     limits = c(12, 24),
@@ -53,7 +52,6 @@ grouped_ggdotplotstats <- function(data,
                                    x,
                                    y,
                                    grouping.var,
-                                   title.prefix = NULL,
                                    output = "plot",
                                    plotgrid.args = list(),
                                    annotation.args = list(),
@@ -61,9 +59,6 @@ grouped_ggdotplotstats <- function(data,
 
   # ======================== preparing dataframe ============================
 
-  # if `title.prefix` is not provided, use the variable `grouping.var` name
-  if (is.null(title.prefix)) title.prefix <- rlang::as_name(rlang::ensym(grouping.var))
-
   # creating a dataframe
   df <-
     dplyr::select(.data = data, {{ grouping.var }}, {{ x }}, {{ y }}) %>%
@@ -72,7 +67,7 @@ grouped_ggdotplotstats <- function(data,
   # creating a list of plots
   plotlist_purrr <-
     purrr::pmap(
-      .l = list(data = df, title = paste0(title.prefix, ": ", names(df))),
+      .l = list(data = df, title = names(df)),
       .f = ggstatsplot::ggdotplotstats,
       x = {{ x }},
       y = {{ y }},
