@@ -52,7 +52,6 @@ grouped_gghistostats <- function(data,
                                  x,
                                  grouping.var,
                                  binwidth = NULL,
-                                 title.prefix = NULL,
                                  output = "plot",
                                  plotgrid.args = list(),
                                  annotation.args = list(),
@@ -74,9 +73,6 @@ grouped_gghistostats <- function(data,
 
   # ======================== preparing dataframe ============================
 
-  # if `title.prefix` is not provided, use the variable `grouping.var` name
-  if (is.null(title.prefix)) title.prefix <- rlang::as_name(rlang::ensym(grouping.var))
-
   # getting the dataframe ready
   df <-
     dplyr::select(.data = data, {{ grouping.var }}, {{ x }}) %>%
@@ -85,7 +81,7 @@ grouped_gghistostats <- function(data,
   # creating a list of plots
   plotlist_purrr <-
     purrr::pmap(
-      .l = list(data = df, title = paste0(title.prefix, ": ", names(df))),
+      .l = list(data = df, title = names(df)),
       .f = ggstatsplot::gghistostats,
       # put common parameters here
       x = {{ x }},
