@@ -144,7 +144,6 @@ test_that(
         grouping.var = "vore",
         xlab = "total sleep",
         ylab = "body weight",
-        title = "mammalian sleep dataset",
         caption = "source: ggplot2 package",
         type = "bayes",
         ggplot.component = scale_y_continuous(breaks = seq(0, 6000, 1000)),
@@ -184,9 +183,8 @@ test_that(
         x = "rating",
         y = length,
         k = 3,
-        conf.level = 0.99,
-        output = "subtitle"
-      )
+        conf.level = 0.99
+      )$expression[[1]]
 
     # tests
     expect_equal(length(ls_results), 1L)
